"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const DocumentationSidebar_1 = require("./DocumentationSidebar");
const DocumentationBox_1 = __importDefault(require("./editor/DocumentationBox"));
const keyboardKeys = {
    ENTER_KEY: "Enter",
    TAB_KEY: "Tab",
    ESCAPE_KEY: "Escape"
};
class MitoCellEditor extends react_1.Component {
    constructor(props) {
        super(props);
        // Set the cell's value
        if (props.charPress != null) {
            /*
            We hack the charPress param. The charPress param is usually used to tell the cell editor
            which character was pressed to enter cell editing mode. However, we use also use it to pass
            the column that the user selected with their mouse. If charPress is not null then either:
              1. the user was in cell editing mode and clicked on a column with their mouse. Then charPress
                 is a stringified JSON object of the form:
                 {
                    "selectedColumn": column
                 }
                 where column is the columnID of the column the user selected with their mouse. This columnID
                 should be appended to the cell editor value to be included in the formula.
      
              2. the user entered cell editing mode by pressing a key instead of Enter or double clicking. In this case,
                 the current cell value should be overwritten by charPress
            */
            if (props.charPress.length > 1) {
                // if a column was passed, append it to the cell's value
                const selectedColumn = JSON.parse(props.charPress).selectedColumn;
                this.state = {
                    value: props.value + selectedColumn,
                    input: null
                };
            }
            else {
                // if a character was passed, overwrite the cell's value
                // TODO: update the spec with this behavior
                this.state = {
                    value: props.charPress,
                    input: null
                };
            }
        }
        else {
            // otherwise keep the original value
            this.state = {
                value: props.value,
                input: null
            };
        }
        // turn on cell editing mode
        const column = props.colDef.field ? props.colDef.field : "";
        props.setEditingMode(true, column, props.rowIndex);
        /* turn off cell editing mode when ENTER or Tab is pressed  */
        document.addEventListener("keydown", (event) => {
            if (event.key === keyboardKeys.ENTER_KEY ||
                event.key === keyboardKeys.TAB_KEY ||
                event.key === keyboardKeys.ESCAPE_KEY) {
                props.setEditingMode(false, "", -1);
            }
        });
        this.getValue = this.getValue.bind(this);
        this.isPopup = this.isPopup.bind(this);
        this.handleOnChange = this.handleOnChange.bind(this);
        this.afterGuiAttached = this.afterGuiAttached.bind(this);
    }
    getValue() {
        return this.state.value;
    }
    /* Make the cell editor a popup, so we can display suggestion/documentation box */
    isPopup() {
        return true;
    }
    /* update the cell value while typing */
    handleOnChange(event) {
        this.setState({
            value: event.target.value
        });
    }
    /*
      This function is called by ag-grid after this component
      is rendered; we simply focus on the input feild rendered
      below so the user can begin typing immediately!
    */
    afterGuiAttached() {
        var _a;
        (_a = this.state.input) === null || _a === void 0 ? void 0 : _a.focus();
    }
    /*
      This function returns the current function that should
      be displayed in the documentation box, based on if the
      documentation box open condition is met.
  
      If the documentation box open condition is not met, this
      returns undefined.
    */
    getDocumentationBoxFunction() {
        var _a;
        // Finds all instances of functions that are not followed by a closing paren
        // e.g. all functions that are still being edited.
        const docBoxRe = /[A-Z]+\((?![^)]*\))/g;
        if (typeof this.state.value == 'string') {
            const functionMatches = (_a = this.state.value) === null || _a === void 0 ? void 0 : _a.match(docBoxRe);
            if (!functionMatches) {
                return undefined;
            }
            // We take the _last_ function that has been written, as this is the funciton
            // being edited currently.
            const lastFunction = functionMatches[functionMatches.length - 1];
            // Strip off the last ( from the function name
            const lastFunctionClean = lastFunction.substr(0, lastFunction.length - 1);
            return DocumentationSidebar_1.functionDocumentationObjects.find((funcDocObject) => {
                return funcDocObject.function === lastFunctionClean;
            });
        }
        return undefined;
    }
    render() {
        const documentationBoxFunction = this.getDocumentationBoxFunction();
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("input", { ref: (input) => { if (!this.state.input) {
                    this.setState({ input: input });
                } }, className: "ag-cell-auto-height ag-cell-inline-editing", name: "value", value: this.state.value, onChange: this.handleOnChange, tabIndex: 1 }),
            documentationBoxFunction &&
                react_1.default.createElement(DocumentationBox_1.default, { funcDocObject: documentationBoxFunction })));
    }
}
exports.default = MitoCellEditor;
//# sourceMappingURL=MitoCellEditor.js.map